##  Transition Timeline
  * January 20, 2026: Deprecation headers added to all Poll API v2 responses. The Poll API v2 is officially deprecated.
  * February 2026 to March 2027: Migration period. Update your integrations to use the Survey API v1. Both APIs remain fully functional.
  * End of March 2027: The Poll API v2 will be removed. The Survey API v1 will become the only available API.
